package handler

import (
	"context"
	"database/sql"
	"errors"
	"net/http"

	pb "git.unistack.org/unistack-org/pkgdash/proto"
	httpsrv "go.unistack.org/micro-server-http/v4"
	"go.unistack.org/micro/v4/logger"
)

func (h *Handler) CommentDelete(ctx context.Context, req *pb.CommentDeleteReq, rsp *pb.CommentDeleteRsp) error {
	logger.Debug(ctx, "Start AddComment")

	err := req.Validate()
	if err != nil {
		logger.Error(ctx, "validate error", err)
		httpsrv.SetRspCode(ctx, http.StatusBadRequest)
		return httpsrv.SetError(NewValidationError(err))
	}

	if err = h.store.CommentDelete(ctx, req); err != nil {

		if errors.Is(err, sql.ErrNoRows) {
			httpsrv.SetRspCode(ctx, http.StatusNotFound)
			return httpsrv.SetError(NewNotFoundError(err))
		}
		logger.Error(ctx, "comment delete error", err)
		httpsrv.SetRspCode(ctx, http.StatusInternalServerError)
		return httpsrv.SetError(NewInternalError(err))
	}

	logger.Debug(ctx, "Success finish addComment")
	return nil
}
