package handler

import (
	"context"
	"net/http"

	"git.unistack.org/unistack-org/pkgdash/internal/models"
	pb "git.unistack.org/unistack-org/pkgdash/proto"
	httpsrv "go.unistack.org/micro-server-http/v4"
	"go.unistack.org/micro/v4/logger"
)

func (h *Handler) HandlerList(ctx context.Context, req *pb.HandlerListReq, rsp *pb.HandlerListRsp) error {
	logger.Debug(ctx, "HandlerList handler start")

	packages, err := h.store.HandlerList(ctx, req)
	if err != nil {
		logger.Error(ctx, "error db response: %v", err)
		httpsrv.SetRspCode(ctx, http.StatusInternalServerError)
		return httpsrv.SetError(NewInternalError(err))
	}

	for _, hdlr := range packages {
		rsp.Handlers = append(rsp.Handlers, models.NewHandler(hdlr))
	}
	logger.Debug(ctx, "HandlerList handler stop")
	return nil
}
