package handler

import (
	"context"
	"net/http"

	"git.unistack.org/unistack-org/pkgdash/internal/models"
	pb "git.unistack.org/unistack-org/pkgdash/proto"
	httpsrv "go.unistack.org/micro-server-http/v4"
	"go.unistack.org/micro/v4/logger"
)

func (h *Handler) PackageList(ctx context.Context, req *pb.PackageListReq, rsp *pb.PackageListRsp) error {
	logger.Debug(ctx, "PackagesList handler start")

	packages, err := h.store.PackageList(ctx, req)
	if err != nil {
		logger.Error(ctx, "error db response: %v", err)
		httpsrv.SetRspCode(ctx, http.StatusInternalServerError)
		return httpsrv.SetError(NewInternalError(err))
	}

	for _, pkg := range packages {
		rsp.Packages = append(rsp.Packages, models.NewPackage(pkg))
	}
	logger.Debug(ctx, "PackagesList handler stop")
	return nil
}
