package handler

import (
	"context"
	"net/http"

	"git.unistack.org/unistack-org/pkgdash/internal/models"
	pb "git.unistack.org/unistack-org/pkgdash/proto"
	httpsrv "go.unistack.org/micro-server-http/v4"
	"go.unistack.org/micro/v4/logger"
)

func (h *Handler) PackageUpdate(ctx context.Context, req *pb.PackageUpdateReq, rsp *pb.PackageUpdateRsp) error {
	logger.Debug(ctx, "Start UpdatePackage")

	if err := req.Validate(); err != nil {
		logger.Error(ctx, "validate error", err)
		httpsrv.SetRspCode(ctx, http.StatusBadRequest)
		return httpsrv.SetError(NewValidationError(err))
	}

	pkg, err := h.store.PackageUpdate(ctx, req)
	if err != nil {
		logger.Error(ctx, "package update error", err)
		httpsrv.SetRspCode(ctx, http.StatusInternalServerError)
		return httpsrv.SetError(NewInternalError(err))
	}

	rsp.Package = models.NewPackage(pkg)

	logger.Debug(ctx, "Success finish UpdatePackage")
	return nil
}
